(*                 Config file of SLAM.m                       *)
(* Put this file into the directory where SLAM.m is located at!*)

(* Path to the executables of spheno, softsusy and suspect*)
ProgramPath["spheno"] = "~/Programs/SPheno/SPheno-3.2.0/bin/SPheno";
ProgramPath["softsusy"] = "~/Programs/softsusy/softsusy-3.3.4/bin/softpoint.x";
ProgramPath["suspect"] = "~/Programs/suspect/suspect2/suspect2";

(* Do not change the following line! *)
$Context="Global`";

(* Default data base link values + temporary LesHouchesFile locations 
   Adjust the rules below to your needs 
   or 
   define corresponding symbols before loading this package  *)

If[Head[#[[1]]]===Symbol,Replace[#, Rule -> Set, 1, Heads -> True]]&/@{
(* Type of data base: "hsqldb"= default Mathematica data base. See Mathematica help for OpenSQLConnection[]. *)
     SQLDataBaseTypeValue->"hsqldb",
(* Defines data base access parameters (Environment["USER"] returns the user name as string )*)
     SQLDataBaseOptionsValue->{"Name" -> "Spectrum", "Username" -> Environment["USER"]},
(* Address of used data base server (Environment["HOME"] returns the home directory path as string )*) 
     SQLDataBaseValue -> (Environment["HOME"]<>"/.SLAM/database/db"),
(* Maximum length of strings saved in data base *)
     SQLVarCharLengthValue-> 50,
(* File path where temporary SLHA generator input files are written (the file name must not be LesHouches.in !) *)
     InputFilePathValue -> (Environment["HOME"]<>"/.SLAM/tmp/SLHA.in"),
(* File path where temporary SLHA generator output files are written *)
     OutputFilePathValue -> (Environment["HOME"]<>"/.SLAM/tmp/SLHA.out")
};



(* Default SM input values for spectrum generators *)
(* Following values are used as default values in Options of 
 WriteSpectrumGeneratorInput and GenerateInputSQLChecklistchosen 
 Adjust the rules below to your needs 
 or 
 define corresponding symbols before loading this package *)
(* PARAMETERLIST *)
If[Head[#[[1]]]===Symbol,#/.Rule->Set]&/@{
invalphaValue->1.279340000*10^2(* 1/alpha(mu=Mz) (MSbar)*),
GFValue->1.16637*10^(-5)(* Fermi-constant *),
asmzValue->0.1184(* Alphas^{(5),MSbar}(Mz) *),
MwValue -> 80.399(* W-Boson mass*),
MzValue -> 91.200000(* Z-Boson mass*),
MbMSbarValue->4.25(* mb(mb) MSbar for spectrum generators only*), 
MtOSValue -> 173.3(* Top mass (Pole) *), 
MtauValue->1.777(* Tau mass (Pole) *), 
(*  msugra STD values                              *)
m0Value -> 1.000000000*10^2,
m12Value -> 2.500000000*10^2,
signmuValue -> 1.000000000,
A0Value -> -1.000000000*10^2,
(*  mgmsb STD values                               *)
lambdaValue -> 40.*10^3,
mmessValue -> 80.*10^3,
nmessValue -> 3.,
(*  mamsb STD values                               *)
m32Value -> 60.*10^3,
(* for low scale benchmark points of hep-ph/0202167  *)
MAValue -> 200.(* Mass of pseudoscalar Higgs-boson A0 *), 
tanbetaValue->10.(* Tan(beta): ration of the vacuum expectation values vu/vd*),
(* for low scale benchmark plains p19MSSM1 and p19MSSM2 hep-ph/1109.3859 *)
M1Value->300.(*p12MSSM1.1*),
M3Value->360.,
(* for low scale benchmark scenario low-mh defined in hep-ph/1302.7033  *)
muValue->1500.(*  bilinear coupling constant of Hu and Hd *),
msleptonValue->400.(*p12MSSM2.12*),
(* for pMSSM Benchmarks for Snowmass 2013 (http://www.slac.stanford.edu/~aismail/snowmass/index.html) *)
xBFS2013Value->0(* Free parameter of Spoke 1 in Bino-squark coannihilation scenario "2342344"*),
yBFS2013Value->0(* Free parameter of Spoke 2 in Bino-squark coannihilation scenario "2342344"*),
muRenValue->173.3(* Renormalisation scale for the DRbar parameters. *)
};




(* 
 Declaration of requested output. 
   ObtainLesHouchesSpectrum[] will return by default the following selection of parameters.
   If you require more/different parameters, add/remove rules below.
   You can chose what ever you like for symbol names in Global`LesHouchesInputRequest,
   as long as they are not assigned to a value during the Mathematica session.
 *)
(* Simple example for LesHouchesInputRequest *)
LesHouchesInputRequest = {
   "ALPHA" -> {
    None -> {alpha, Real}},
   "SPINFO" -> {
     1 -> {SLHAGen, String}},
   "HMIX" -> {
     2 -> {tanbeta, Real}}};


(*
(* A more involved example for LesHouchesInputRequest *)
LesHouchesInputRequest = {
   "ALPHA" -> {
    None -> {alpha, Real}},
   "SMINPUTS" -> {
     2 -> {GF, Real},
     3 -> {asmz, Real},
     4 -> {Mz, Real},
     5 -> {mb, Real},
     6 -> {MtOS, Real}},
   "SPINFO" -> {
     1 -> {SLHAGenerator, String},
     2 -> {SLHAGeneratorVersion, String},
     3 -> {SLHAWarning, String},
     4 -> {SLHAError, String}},
   "GAUGE" -> {
     1 -> {g1, Real},
     2 -> {g2, Real},
     3 -> {g3, Real}},
   "HMIX" -> {
     1 -> {muSUSY, Real},
     2 -> {tanbeta, Real},
     3 -> {higgsvev, Real}},
   "MSOFT" -> {
     BI->{muRen, Real},(* using the Block Info (BI) as real number leads to dropping the "Q= " string *)
     3 -> {Mgl, Real},
     21 -> {SBMH12, Real},
     22 -> {SBMH22, Real},
     41 -> {SBMSQ1, Real},
     42 -> {SBMSQ2, Real},
     43 -> {SBMSQ3, Real},
     44 -> {SBMSu, Real},
     45 -> {SBMSc, Real},
     46 -> {SBMSt, Real},
     47 -> {SBMSd, Real},
     48 -> {SBMSs, Real},
     49 -> {SBMSb, Real}},
   "AU" -> {
     {1, 1} -> {Au, Real},
     {2, 2} -> {Ac, Real},
     {3, 3} -> {At, Real}},
   "AD" -> {
     {1, 1} -> {Ad, Real},
     {2, 2} -> {As, Real},
     {3, 3} -> {Ab, Real}},
   "YU" -> {
     {3, 3} -> {Yt, Real}},
   "YD" -> {
     {3, 3} -> {Yb, Real}},
   "MASS" -> {
     25 -> {Mh, Real},
     36 -> {MA, Real},
     1000021 -> {MglOS, Real},
     1000001 -> {MsdLOS, Real},
     1000002 -> {MsuLOS, Real},
     1000003 -> {MssLOS, Real},
     1000004 -> {MscLOS, Real},
     1000005 -> {Msb1OS, Real},
     1000006 -> {Mst1OS, Real},
     2000001 -> {MsdROS, Real},
     2000002 -> {MsuROS, Real},
     2000003 -> {MssROS, Real},
     2000004 -> {MscROS, Real},
     2000005 -> {Msb2OS, Real},
     2000006 -> {Mst2OS, Real}},
   "STOPMIX" -> {
     {1, 1} -> {fst11, Real},
     {1, 2} -> {fst12, Real},
     {2, 1} -> {fst21, Real},
     {2, 2} -> {fst22, Real}},
   "SBOTMIX" -> {
     {1, 1} -> {fsb11, Real},
     {1, 2} -> {fsb12, Real},
     {2, 1} -> {fsb21, Real},
     {2, 2} -> {fsb22, Real}}};

*)



(* Selection for Minimal-Flavour-Violation:
 UseMinimalFlavourViolation=True -> Only minimal flavour violation is allowed
 UseMinimalFlavourViolation=False -> beyond minimal flavour violation is allowed  
*)
UseMinimalFlavourViolation=True;

(* Declaration of entry value formats.
 The following declarations enter the SQL data base.
 Each entry leads to a seperate column in data base. 
 If you have additional entries to be saved in data base you have to add a declaration here! 
*)

If[Head[#[[1]]]===Symbol,Replace[#, Rule -> Set, 1, Heads -> True]]&/@ Which[(*Minimal-Flavour-Violation Set*) UseMinimalFlavourViolation,
{LesHouchesInputSQLFormats->{
   "SPHENOINPUT" -> {
     11 -> Integer,
     21 -> Integer
     },
   "SOFTSUSY" -> {
     5 -> Real
     },
   "SU_ALGO" -> {
     2 -> Integer
     },
   "MODSEL" -> {
     1 -> Integer,
     12 -> Real,
     11 -> Integer
     },
   "SMINPUTS" -> {
     1 -> Real,
     2 -> Real,
     3 -> Real,
     4 -> Real,
     5 -> Real,
     6 -> Real,
     7 -> Real
     },
   "MINPAR" -> {
     1 -> Real,
     2 -> Real,
     3 -> Real,
     4 -> Real,
     5 -> Real},
   "EXTPAR" -> {
     0 -> Real,
     1 -> Real,
     2 -> Real,
     3 -> Real,
     11 -> Real,
     12 -> Real,
     13 -> Real,
     23 -> Real,
     26 -> Real,
     31 -> Real,
     32 -> Real,
     33 -> Real,
     34 -> Real,
     35 -> Real,
     36 -> Real,
     41 -> Real,
     42 -> Real,
     43 -> Real,
     44 -> Real,
     45 -> Real,
     46 -> Real,
     47 -> Real,
     48 -> Real,
     49 -> Real}},
LesHouchesOutputSQLFormats->({
   "SPHENOINFO"->{
    1->Integer,
    2->Integer},
   "MODSEL"->{
    1->Integer},
   "MINPAR"->{
    1->Real,
    2->Real,
    3->Real,
    4->Real,
    5->Real},
   "MASS"->{
    24->Real,
    25->Real,
    35->Real,
    36->Real,
    37->Real,
    1000001->Real,
    1000002->Real,
    1000003->Real,
    1000004->Real,
    1000005->Real,
    1000006->Real,
    1000011->Real,
    1000012->Real,
    1000013->Real,
    1000014->Real,
    1000015->Real,
    1000016->Real,
    1000021->Real,
    1000022->Real,
    1000023->Real,
    1000024->Real,
    1000025->Real,
    1000035->Real,
    1000037->Real,
    2000001->Real,
    2000002->Real,
    2000003->Real,
    2000004->Real,
    2000005->Real,
    2000006->Real,
    2000011->Real,
    2000013->Real,
    2000015->Real},
   "NMIX"->{
    {1,1}->Real,
    {1,2}->Real,
    {1,3}->Real,
    {1,4}->Real,
    {2,1}->Real,
    {2,2}->Real,
    {2,3}->Real,
    {2,4}->Real,
    {3,1}->Real,
    {3,2}->Real,
    {3,3}->Real,
    {3,4}->Real,
    {4,1}->Real,
    {4,2}->Real,
    {4,3}->Real,
    {4,4}->Real},
   "UMIX"->{
    {1,1}->Real,
    {1,2}->Real,
    {2,1}->Real,
    {2,2}->Real},
   "VMIX"->{
    {1,1}->Real,
    {1,2}->Real,
    {2,1}->Real,
    {2,2}->Real},
   "STOPMIX"->{
    {1,1}->Real,
    {1,2}->Real,
    {2,1}->Real,
    {2,2}->Real},
   "SBOTMIX"->{
    {1,1}->Real,
    {1,2}->Real,
    {2,1}->Real,
    {2,2}->Real},
   "STAUMIX"->{
    {1,1}->Real,
    {1,2}->Real,
    {2,1}->Real,
    {2,2}->Real},
   "ALPHA" -> {
    None -> Real},
   "SMINPUTS" -> {
     1 -> Real,
     2 -> Real,
     3 -> Real,
     4 -> Real,
     5 -> Real,
     6 -> Real,
     7 -> Real},
   "SPINFO" -> {
     1 -> String,
     2 -> String,
     3 -> String,
     4 -> String},
   "GAUGE" -> {
     1 -> Real,
     2 -> Real,
     3 -> Real},
   "HMIX" -> {
     1 -> Real,
     2 -> Real,
     3 -> Real,
     4 -> Real},
   "AU" -> {
     {1, 1} -> Real,
     {2, 2} -> Real,
     {3, 3} -> Real},
   "AD" -> {
     {1, 1} -> Real,
     {2, 2} -> Real,
     {3, 3} -> Real},
   "AE" -> {
     {1, 1} -> Real,
     {2, 2} -> Real,
     {3, 3} -> Real},
   "YU" -> {
     {1, 1} -> Real,
     {2, 2} -> Real,
     {3, 3} -> Real},
   "YD" -> {
     {1, 1} -> Real,
     {2, 2} -> Real,
     {3, 3} -> Real},
   "YE" -> {
     {1, 1} -> Real,
     {2, 2} -> Real,
     {3, 3} -> Real},
   "MSOFT"->{
     1->Real,
     2->Real,
     3->Real,
     21->Real,
     22->Real,
     31->Real,
     32->Real,
     33->Real,
     34->Real,
     35->Real,
     36->Real,
     41->Real,
     42->Real,
     43->Real,
     44->Real,
     45->Real,
     46->Real,
     47->Real,
     48->Real,
     49->Real},
    "SPHENOLOWENERGY"->{
     1->Real,
     2->Real,
     3->Real,
     4->Real,
     5->Real,
     6->Real,
     7->Real,
     10->Real,
     11->Real,
     12->Real,
     13->Real,
     14->Real,
     15->Real,
     16->Real,
     17->Real,
     18->Real,
     19->Real,
     20->Real,
     21->Real,
     30->Real,
     39->Real,(*added Jul 18 2012*)
     40->Real,
     41->Real,
     42->Real}})},
(*Non-Minimal-Flavour-Violation Set*)!UseMinimalFlavourViolation,
{LesHouchesInputSQLFormats->{
   "SPHENOINPUT" -> {
     11 -> Integer,
     21 -> Integer
     },
   "SOFTSUSY" -> {
     5 -> Integer
     },
   "SU_ALGO" -> {
     2 -> Integer
     },
   "MODSEL" -> {
     1 -> Integer,
     6 -> Integer,
     11 -> Integer,
     12 -> Real
     },
   "SMINPUTS" -> {
     1 -> Real,
     2 -> Real,
     3 -> Real,
     4 -> Real,
     5 -> Real,
     6 -> Real,
     7 -> Real
     },
   "MINPAR" -> {
     1 -> Real,
     2 -> Real,
     3 -> Real,
     4 -> Real,
     5 -> Real},
   "EXTPAR" -> {
     0 -> Real,
     1 -> Real,
     2 -> Real,
     3 -> Real,
     11 -> Real,
     12 -> Real,
     13 -> Real,
     21 -> Real,
     22 -> Real,
     23 -> Real,
     25 -> Real,
     26 -> Real,
     31 -> Real,
     32 -> Real,
     33 -> Real,
     34 -> Real,
     35 -> Real,
     36 -> Real,
     41 -> Real,
     42 -> Real,
     43 -> Real,
     44 -> Real,
     45 -> Real,
     46 -> Real,
     47 -> Real,
     48 -> Real,
     49 -> Real},
    "MSQ2IN" -> {
      {1,1} -> Real,
      {1,2} -> Real,
      {1,3} -> Real,
      {2,2} -> Real,
      {2,3} -> Real,      
      {3,3} -> Real
      },
     "MSU2IN" -> {
      {1,1} -> Real,
      {1,2} -> Real,
      {1,3} -> Real,
      {2,2} -> Real,
      {2,3} -> Real,      
      {3,3} -> Real
      },
      "MSD2IN" -> {
      {1,1} -> Real,
      {1,2} -> Real,
      {1,3} -> Real,
      {2,2} -> Real,
      {2,3} -> Real,      
      {3,3} -> Real
      },
      "MSL2IN" -> {
      {1,1} -> Real,
      {1,2} -> Real,
      {1,3} -> Real,
      {2,2} -> Real,
      {2,3} -> Real,      
      {3,3} -> Real
      },
      "MSE2IN" -> {
      {1,1} -> Real,
      {1,2} -> Real,
      {1,3} -> Real,
      {2,2} -> Real,
      {2,3} -> Real,      
      {3,3} -> Real
      },
      "TDIN" -> {
      {1,1} -> Real,
      {1,2} -> Real,
      {1,3} -> Real,
      {2,1} -> Real,
      {2,2} -> Real,
      {2,3} -> Real,
      {3,1} -> Real,
      {3,2} -> Real,
      {3,3} -> Real
      },
      "TUIN" -> {
      {1,1} -> Real,
      {1,2} -> Real,
      {1,3} -> Real,
      {2,1} -> Real,
      {2,2} -> Real,
      {2,3} -> Real,
      {3,1} -> Real,
      {3,2} -> Real,
      {3,3} -> Real
      },
      "TEIN" -> {
      {1,1} -> Real,
      {1,2} -> Real,
      {1,3} -> Real,
      {2,1} -> Real,
      {2,2} -> Real,
      {2,3} -> Real,
      {3,1} -> Real,
      {3,2} -> Real,
      {3,3} -> Real
      }
},
LesHouchesOutputSQLFormats->({
   "SPHENOINFO"->{
    1->Integer,
    2->Integer},
   "MODSEL"->{
    1->Integer},
   "MINPAR"->{
    1->Real,
    2->Real,
    3->Real,
    4->Real,
    5->Real},
   "MASS"->{
    24->Real,
    25->Real,
    35->Real,
    36->Real,
    37->Real,
    1000001->Real,
    1000002->Real,
    1000003->Real,
    1000004->Real,
    1000005->Real,
    1000006->Real,
    1000011->Real,
    1000012->Real,
    1000013->Real,
    1000014->Real,
    1000015->Real,
    1000016->Real,
    1000021->Real,
    1000022->Real,
    1000023->Real,
    1000024->Real,
    1000025->Real,
    1000035->Real,
    1000037->Real,
    2000001->Real,
    2000002->Real,
    2000003->Real,
    2000004->Real,
    2000005->Real,
    2000006->Real,
    2000011->Real,
    2000013->Real,
    2000015->Real},
   "NMIX"->{
    {1,1}->Real,
    {1,2}->Real,
    {1,3}->Real,
    {1,4}->Real,
    {2,1}->Real,
    {2,2}->Real,
    {2,3}->Real,
    {2,4}->Real,
    {3,1}->Real,
    {3,2}->Real,
    {3,3}->Real,
    {3,4}->Real,
    {4,1}->Real,
    {4,2}->Real,
    {4,3}->Real,
    {4,4}->Real},
   "UMIX"->{
    {1,1}->Real,
    {1,2}->Real,
    {2,1}->Real,
    {2,2}->Real},
   "VMIX"->{
    {1,1}->Real,
    {1,2}->Real,
    {2,1}->Real,
    {2,2}->Real},
   "STOPMIX"->{
    {1,1}->Real,
    {1,2}->Real,
    {2,1}->Real,
    {2,2}->Real},
   "SBOTMIX"->{
    {1,1}->Real,
    {1,2}->Real,
    {2,1}->Real,
    {2,2}->Real},
   "STAUMIX"->{
    {1,1}->Real,
    {1,2}->Real,
    {2,1}->Real,
    {2,2}->Real},
   "ALPHA" -> {
    None -> Real},
   "SMINPUTS" -> {
     1 -> Real,
     2 -> Real,
     3 -> Real,
     4 -> Real,
     5 -> Real,
     6 -> Real,
     7 -> Real},
   "SPINFO" -> {
     1 -> String,
     2 -> String,
     3 -> String,
     4 -> String},
   "GAUGE" -> {
     1 -> Real,
     2 -> Real,
     3 -> Real},
   "HMIX" -> {
     1 -> Real,
     2 -> Real,
     3 -> Real,
     4 -> Real},
   "AU" -> {
     {1, 1} -> Real,
     {2, 2} -> Real,
     {3, 3} -> Real},
   "AD" -> {
     {1, 1} -> Real,
     {2, 2} -> Real,
     {3, 3} -> Real},
   "AE" -> {
     {1, 1} -> Real,
     {2, 2} -> Real,
     {3, 3} -> Real},
   "YU" -> {
     {1, 1} -> Real,
     {2, 2} -> Real,
     {3, 3} -> Real},
   "YD" -> {
     {1, 1} -> Real,
     {2, 2} -> Real,
     {3, 3} -> Real},
   "YE" -> {
     {1, 1} -> Real,
     {2, 2} -> Real,
     {3, 3} -> Real},
   "MSOFT"->{
     1->Real,
     2->Real,
     3->Real,
     21->Real,
     22->Real,
     31->Real,
     32->Real,
     33->Real,
     34->Real,
     35->Real,
     36->Real,
     41->Real,
     42->Real,
     43->Real,
     44->Real,
     45->Real,
     46->Real,
     47->Real,
     48->Real,
     49->Real},
    "SPHENOLOWENERGY"->{
     1->Real,
     2->Real,
     3->Real,
     4->Real,
     5->Real,
     6->Real,
     7->Real,
     10->Real,
     11->Real,
     12->Real,
     13->Real,
     14->Real,
     15->Real,
     16->Real,
     17->Real,
     18->Real,
     19->Real,
     20->Real,
     21->Real,
     30->Real,
     40->Real,
     41->Real,
     42->Real}})
}
];

(* Do not change the following line! *)
$Context="SLAM`Private`";

